@@ -236,8 +236,7 @@ class JsonParseNode(ParseNode, Generic[T, U]):
         base64_string = self.get_str_value()
         if not base64_string:
             return None
-        base64_bytes = base64_string.encode("utf-8")
-        return base64.b64decode(base64_bytes)
+        return base64_string.encode("utf-8")
 
     def get_on_before_assign_field_values(self) -> Optional[Callable[[Parsable], None]]:
         """Gets the callback called before the node is deserialized.
